@@ -35,7 +35,7 @@ import urllib.parse
 import uuid
 import zipfile
 from collections import OrderedDict
-from contextlib import redirect_stdout
+from contextlib import redirect_stdout, redirect_stderr
 
 import portalocker
 from watchgod import awatch
@@ -49,7 +49,6 @@ except ImportError:
     gunicorn = None
 
 import click
-import jwt  # this is PyJWT
 
 # Third party modules
 import ombott as bottle
@@ -61,6 +60,8 @@ import renoir.writers
 import threadsafevariable
 import yatl
 
+from .utils.misc import secure_dumps, secure_loads
+
 bottle.DefaultConfig.max_memfile_size = 16 * 1024 * 1024
 bottle.DefaultConfig.app_name_header = "HTTP_X_PY4WEB_APPNAME"
 # apply DefaultConfig changes to default_app
@@ -605,7 +606,7 @@ class Session(Fixture):
         secret is the shared key used to encrypt the session (using algorithm)
         expiration is in seconds
         (optional) storage must have a get(key) and set(key,value,expiration) methods
-        if not provided session is stored in jwt cookie else the jwt is stored in storage and its uuid key is stored in the cookie
+        session is stored signed and encrypted in the cookie
         """
         # assert Session.SECRET, "Missing Session.SECRET"
         self.secret = secret or Session.SECRET
@@ -646,16 +647,17 @@ class Session(Fixture):
         if Fixture.__fixture_debug__:
             logging.debug("Session token found %s", raw_token)
         if raw_token:
-            token_data = raw_token.encode()
             try:
                 if self.storage:
+                    token_data = raw_token.encode()
                     json_data = self.storage.get(token_data)
                     if json_data:
                         self_local.data = json.loads(json_data)
                 else:
-                    self_local.data = jwt.decode(
-                        token_data, self.secret, algorithms=[self.algorithm]
-                    )
+                    try:
+                        self_local.data = secure_loads(raw_token, self.secret.encode())
+                    except (AssertionError, json.JSONDecodeError):
+                        self_local.data = {}
                 if self.expiration is not None and self.storage is None:
                     assert self_local.data["timestamp"] > time.time() - int(
                         self.expiration
@@ -681,14 +683,9 @@ class Session(Fixture):
             cookie_data = self_local.data["uuid"]
             self.storage.set(cookie_data, json.dumps(self_local.data), self.expiration)
         else:
-            cookie_data = jwt.encode(
-                self_local.data, self.secret, algorithm=self.algorithm
-            )
-            if isinstance(cookie_data, bytes):
-                cookie_data = cookie_data.decode()
+            cookie_data = secure_dumps(self_local.data, self.secret.encode())
         if Fixture.__fixture_debug__:
             logging.debug("Session stored %s", cookie_data)
-
         response.set_cookie(
             self_local.session_cookie_name,
             cookie_data,
@@ -1224,6 +1221,14 @@ error_logger = ErrorLogger()
 #########################################################################################
 
 
+class StreamProxy:
+    def __init__(self, stream):
+        self._stream = stream
+
+    def write(self, *args, **kwargs):
+        return self._stream.write(*args, **kwargs)
+
+
 class Reloader:
 
     ROUTES = collections.defaultdict(list)
@@ -1303,14 +1308,20 @@ class Reloader:
                     del Reloader.MODULES[app_name]
                     clear_modules()
 
-                load_module_stdout = io.StringIO()
-                with redirect_stdout(load_module_stdout):
+                load_module_message = None
+                buf_out = StreamProxy(io.StringIO())
+                buf_err = StreamProxy(buf_out._stream)
+                with redirect_stdout(buf_out), redirect_stderr(buf_err):
                     module = importlib.machinery.SourceFileLoader(
                         module_name, init
                     ).load_module()
-                load_module_message = load_module_stdout.getvalue()
-                if len(load_module_message):
-                    click.secho("\x1b[A    stdout %s       " % app_name, fg="yellow")
+                    load_module_message = buf_out._stream.getvalue()
+                buf_out._stream.close()
+                buf_out._stream = sys.stdout
+                buf_err._stream = sys.stderr
+
+                if load_module_message:
+                    click.secho("\x1b[A    output %s       " % app_name, fg="yellow")
                     click.echo(load_module_message)
 
                 click.secho("\x1b[A[X] loaded %s       " % app_name, fg="green")
@@ -1532,7 +1543,8 @@ def start_server(kwargs):
     port = int(kwargs["port"])
     apps_folder = kwargs["apps_folder"]
     number_workers = kwargs["number_workers"]
-    params = dict(host=host, port=port, reloader=False)
+    quiet = kwargs["quiet"]
+    params = dict(host=host, port=port, reloader=False, quiet=quiet)
     server_config = dict(
         platform=platform.system().lower(),
         server=None if kwargs["server"] == "default" else kwargs["server"],
@@ -1541,7 +1553,7 @@ def start_server(kwargs):
 
     if not server_config["server"]:
         if server_config["platform"] == "windows" or number_workers < 2:
-            server_config["server"] = "rocket"
+            server_config["server"] = "rocketServer"
         else:
             if not gunicorn:
                 logging.error("gunicorn not installed")
@@ -1549,7 +1561,7 @@ def start_server(kwargs):
             server_config["server"] = "gunicorn"
 
     # Catch interrupts like Ctrl-C if needed
-    if server_config["server"] not in {"rocket", "wsgirefWsTwistedServer"}:
+    if server_config["server"] not in {"rocketServer", "wsgirefWsTwistedServer"}:
         signal.signal(
             signal.SIGINT,
             lambda signal, frame: click.echo(
@@ -1882,6 +1894,14 @@ def new_app(apps_folder, app_name, yes, scaffold_zip):
     help="File for the encrypted password",
     show_default=True,
 )
+@click.option(
+    "-Q",
+    "--quiet",
+    is_flag=True,
+    default=False,
+    help="Suppress server output",
+    show_default=True,
+)
 @click.option(
     "-s",
     "--server",
