@@ -8,8 +8,15 @@ import time
 import urllib
 import uuid
 
-from pydal.validators import (CRYPT, IS_EMAIL, IS_EQUAL_TO, IS_MATCH,
-                              IS_NOT_EMPTY, IS_NOT_IN_DB, IS_STRONG)
+from pydal.validators import (
+    CRYPT,
+    IS_EMAIL,
+    IS_EQUAL_TO,
+    IS_MATCH,
+    IS_NOT_EMPTY,
+    IS_NOT_IN_DB,
+    IS_STRONG,
+)
 from yatl.helpers import DIV, A
 
 from py4web import HTTP, URL, Field, action, redirect, request, response
@@ -31,13 +38,22 @@ from py4web.utils.param import Param
 
 
 def b16e(text):
+    """convert unicode to b16 unicode"""
     return base64.b16encode(text.encode()).decode()
 
 
 def b16d(text):
+    """convert unicode to b16 unicode"""
     return base64.b16decode(text.encode()).decode()
 
 
+def prevent_open_redirect(url):
+    """url must be a valid absolute URL whithout schema"""
+    if url and url[0] == "/" and "//" not in url:
+        return url
+    return None
+
+
 class AuthEnforcer(Fixture):
     """Base fixture that checks if a condition is met.
 
@@ -197,6 +213,7 @@ class Auth(Fixture):
         password_in_db=True,
     ):
 
+        # configuration parameters
         self.param = Param(
             registration_requires_confirmation=registration_requires_confirmation,
             registration_requires_approval=registration_requires_approval,
@@ -216,6 +233,9 @@ class Auth(Fixture):
             exclude_extra_fields_in_profile=None,
         )
 
+        # callbacks for forms
+        self.on_accept = {}
+
         self.__prerequisites__ = []
         self.inject = inject
         if session:
@@ -1121,9 +1141,7 @@ class AuthAPI:
         payload = request.POST if (request.json is None) else request.json
 
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         auth.get_or_delete_existing_unverified_account(payload.get("email"))
         return auth.register(payload, send=True).as_dict()
 
@@ -1136,9 +1154,7 @@ class AuthAPI:
         payload = request.POST if (request.json is None) else request.json
 
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         username, password = payload.get("email"), payload.get("password")
         if not all(isinstance(_, str) for _ in [username, password]):
             return auth._error(auth.param.messages["errors"].get("invalid_credentials"))
@@ -1186,9 +1202,7 @@ class AuthAPI:
         payload = request.POST if (request.json is None) else request.json
 
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
 
         if "email" not in payload:
             payload["email"] = ""
@@ -1209,9 +1223,7 @@ class AuthAPI:
 
         # check the new_password2 only if passed
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         return auth.reset_password(
             payload.get("token"),
             payload.get("new_password"),
@@ -1257,9 +1269,7 @@ class AuthAPI:
         payload = request.POST if (request.json is None) else request.json
 
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         return auth.change_password(
             auth.get_user(safe=False),  # refactor make faster
             payload.get("new_password"),
@@ -1273,9 +1283,7 @@ class AuthAPI:
         payload = request.POST if (request.json is None) else request.json
 
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         return auth.change_email(
             auth.get_user(safe=False),
             payload.get("new_email"),
@@ -1292,13 +1300,11 @@ class AuthAPI:
 
         if request.method == "GET":
             return {"user": auth.get_user()}
-        
+
         payload = request.POST if (request.json is None) else request.json
-        
+
         if payload is None:
-            return auth._error(
-                auth.param.messages["errors"].get("no_post_payload")
-            )
+            return auth._error(auth.param.messages["errors"].get("no_post_payload"))
         else:
             return auth.update_profile(auth.get_user(), **payload)
 
@@ -1442,8 +1448,9 @@ class DefaultAuthForms:
         for name, plugin in self.auth.plugins.items():
             url = f"/auth/plugin/{name}/login"
 
-            if request.query.get("next"):
-                url = f"{url}?next={request.query.get('next')}"
+            next_url = prevent_open_redirect(request.query.get("next"))
+            if next_url:
+                url = f"{url}?next={next_url}"
 
             if (
                 name != "email_auth"
@@ -1524,7 +1531,8 @@ class DefaultAuthForms:
             formstyle=self.formstyle,
         )
         user = None
-        self.auth.session["_next_login"] = request.query.get("next")
+        next_url = prevent_open_redirect(request.query.get("next"))
+        self.auth.session["_next_login"] = next_url
         if form.submitted:
             user, error = self.auth.login(
                 form.vars.get("email", ""), form.vars.get("password", "")
@@ -1557,7 +1565,7 @@ class DefaultAuthForms:
         return form
 
     def request_reset_password(self, model=False):
-        """"Request reset password form"""
+        """ "Request reset password form"""
         fields = [
             Field(
                 "email",
@@ -1813,5 +1821,7 @@ class DefaultAuthForms:
         self.auth.flash.set(self.auth.param.messages["flash"].get(key, key))
 
     def _postprocessing(self, action, form=None, user=None):
+        if action in self.auth.on_accept:
+            self.auth.on_accept[action](form, user)
         if not form or form.accepted:
             redirect(self.auth.session.get(f"_next_{action}") or URL("index"))
