@@ -12,35 +12,28 @@ Background processes made simple
 
 from __future__ import print_function
 
-import socket
-import os
+import datetime
 import logging
+import multiprocessing
+import os
+import re
+import signal
+import socket
+import sys
+import tempfile
+import threading
+import time
+import traceback
 import types
 from functools import reduce
-import datetime
-import re
-import sys
-from json import loads, dumps
-import tempfile
-import traceback
-import threading
-import multiprocessing
-import time
-import signal
+from json import dumps, loads
 
-from gluon import DAL, Field, IS_NOT_EMPTY, IS_IN_SET, IS_NOT_IN_DB, IS_EMPTY_OR
-from gluon import IS_INT_IN_RANGE, IS_DATETIME, IS_IN_DB
-from gluon.utils import web2py_uuid
-from gluon._compat import (
-    Queue,
-    long,
-    iteritems,
-    PY2,
-    to_bytes,
-    string_types,
-    integer_types,
-)
+from gluon import (DAL, IS_DATETIME, IS_EMPTY_OR, IS_IN_DB, IS_IN_SET,
+                   IS_INT_IN_RANGE, IS_NOT_EMPTY, IS_NOT_IN_DB, Field)
+from gluon._compat import (PY2, Queue, integer_types, iteritems, long,
+                           string_types, to_bytes)
 from gluon.storage import Storage
+from gluon.utils import web2py_uuid
 
 USAGE = """
 ## Example
@@ -512,8 +505,8 @@ def executor(retq, task, outq):
     stdout = LogOutput(outq)
     try:
         if task.app:
-            from gluon.shell import env, parse_path_info
             from gluon import current
+            from gluon.shell import env, parse_path_info
 
             ## FIXME: why temporarily change the log level of the root logger?
             # level = logging.getLogger().getEffectiveLevel()
